Maximum share of each feed item that can be allocated to each livestock
category. Used by redistribute_feed() to cap feed distribution.
Maximum share of each feed item that can be allocated to each livestock
category. Used by redistribute_feed() to cap feed distribution.